Learn R Programming

drughelper (version 0.2.0)

Drug_response: DrugResponse

Description

A data.frame from BeatAML project with a set of inhibition drugs and other information

Usage

data("drugResponse")

Arguments

Format

A data frame with 47650 observations on the following 4 variables.

inhibitor

gen target and drug name

lab_id

an identification code

ic50

ic50 value

auc

auc value

Details

This dataset is used in the first case study where drugs from the BeatAML project are cross-studied with other different datasets. ic50 and auc values are experimental results incorporated to the dataset

Examples

Run this code
# NOT RUN {
data(Drug_response)
## maybe str(Drug_response) ; plot(Drug_response) ...
# }

Run the code above in your browser using DataLab