Learn R Programming

drughelper (version 0.2.0)

checkDrugSynonym: Check for drug synonyms

Description

Given an input of drug synonyms, check if those drugs are approved and find a proper more used synonym

Usage

checkDrugSynonym(drugVector)

Arguments

drugVector

A string vector of undefined length, with Drug names

Value

A dataframe containing: the input drug name, if it is approved or not, drughelper ID and a proper-more used synonym.

Examples

Run this code
# NOT RUN {
checkDrugSynonym(c("Procaine", "Furazosin", "Embelin"))
# }

Run the code above in your browser using DataLab