Learn R Programming

drughelper (version 0.2.0)

formattingDrugName: Normalization of drug names

Description

This function corrects and capitalizes the names of a given vector of drugs.

Usage

formattingDrugName(DrugName)

Arguments

DrugName

A string with the name of the drug to be normalized

Value

A string containing only alphanumeric content of the input drug and capitalized

Examples

Run this code
# NOT RUN {
formattingDrugName("morphine")
# }

Run the code above in your browser using DataLab