powered by
Given an input of drug synonyms, check if those drugs are approved and find a proper more used synonym
checkDrugSynonym(drugVector)
A string vector of undefined length, with Drug names
A dataframe containing: the input drug name, if it is approved or not, drughelper ID and a proper-more used synonym.
# NOT RUN { checkDrugSynonym(c("Procaine", "Furazosin", "Embelin")) # }
Run the code above in your browser using DataLab