powered by
This function corrects and capitalizes the names of a given vector of drugs.
formattingDrugName(DrugName)
A string with the name of the drug to be normalized
A string containing only alphanumeric content of the input drug and capitalized
# NOT RUN { formattingDrugName("morphine") # }
Run the code above in your browser using DataLab